[Lldb-commits] [lldb] r129895 - /lldb/trunk/test/command_regex/TestCommandRegex.py

Johnny Chen johnny.chen at apple.com
Wed Apr 20 17:05:59 PDT 2011


Author: johnny
Date: Wed Apr 20 19:05:59 2011
New Revision: 129895

URL: http://llvm.org/viewvc/llvm-project?rev=129895&view=rev
Log:
Replace 'commands' with 'command', and update to the latest prompt.

Modified:
    lldb/trunk/test/command_regex/TestCommandRegex.py

Modified: lldb/trunk/test/command_regex/TestCommandRegex.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/command_regex/TestCommandRegex.py?rev=129895&r1=129894&r2=129895&view=diff
==============================================================================
--- lldb/trunk/test/command_regex/TestCommandRegex.py (original)
+++ lldb/trunk/test/command_regex/TestCommandRegex.py Wed Apr 20 19:05:59 2011
@@ -13,9 +13,9 @@
     mydir = "command_regex"
 
     def test_command_regex(self):
         """Test a simple scenario of 'commands regexp' invocation and subsequent use."""
         prompt = "\(lldb\) "
-        regex_prompt = "Enter multiple regular expressions in the form s/find/replace/ then terminate with an empty line:\r\n"
+        regex_prompt = "Enter regular expressions in the form 's/<regex>/<subst>/' and terminate with an empty line:\r\n"
         regex_prompt1 = "\r\n"
 
         child = pexpect.spawn('%s' % self.lldbExec)
@@ -25,7 +25,7 @@
 
         # Substitute 'Help!' with 'help' using the 'commands regex' mechanism.
         child.expect(prompt)
-        child.sendline('commands regex Help!')
+        child.sendline("command regex 'Help!'")
         child.expect(regex_prompt)
         child.sendline('s/^$/help/')
         child.expect(regex_prompt1)
@@ -13,9 +13,9 @@
 
     def test_command_regex(self):
-        """Test a simple scenario of 'commands regexp' invocation and subsequent use."""
+        """Test a simple scenario of 'command regexp' invocation and subsequent use."""
         prompt = "\(lldb\) "





More information about the lldb-commits mailing list